@@ -14,6 +14,7 @@ from reV import __version__
 
 
 @click.group()
+@click.version_option(version=__version__)
 @click.option('--name', '-n', default='reV-batch', type=STR,
               help='reV batch name, by default "reV-batch".')
 @click.option('-v', '--verbose', is_flag=True,
@@ -26,14 +27,6 @@ def main(ctx, name, verbose):
     ctx.obj['NAME'] = name
 
 
-@main.command()
-def version():
-    """
-    print version
-    """
-    click.echo(__version__)
-
-
 @main.command()
 def valid_config_keys():
     """
